

def find_folder_id_by_name(folders, folder_name):
    for folder in folders:
        if folder['name'] == folder_name:
            return folder['id']  # Возвращаем ID папки, если нашли

        # Если у папки есть дочерние элементы, продолжаем поиск в них
        if folder.get('children'):
            child_id = find_folder_id_by_name(folder['children'], folder_name)
            if child_id:
                return child_id

    return None  # Если папка с нужным именем не найдена


def get_or_create_folder(api_client, folders, folder_name):
    # Дерево папок
    folder_tree = folders.get('children', [])

    # Ищем папку по имени
    folder_id = find_folder_id_by_name(folder_tree, folder_name)

    if folder_id:
        print(f"Папка '{folder_name}' найдена, ID: {folder_id}")
        return folder_id
    else:
        print(f"Папка '{folder_name}' не найдена, создаем новую.")
        # Если не нашли, создаем папку в корне (без parent_id)
        folder_id = api_client.create_test_run_folder(folder_name)
        print(f"Создана папка '{folder_name}', ID: {folder_id}")
        return folder_id



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="pytest_zephyr_scale_integration",
    version="0.1.17",
    author="Sergey Popov",
    maintainer="Sergey Popov",
    author_email="sergey1404sergey@mail.ru",
    maintainer_email="sergey1404sergey@mail.ru",
    description="A library for integrating Jira Zephyr Scale (Adaptavist\TM4J) with pytest",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/PROaction/pytest-zephyr-scale-integration",
    license="MIT",
    packages=find_packages(),
    keywords="zephyr, zephyr-scale, adaptavist, TM4J, pytest, autocreate test cycle, pytest zephyr integration",
    install_requires=[
        "pytest",
        "python-dotenv",
        "requests",
        "requests-toolbelt",
    ],
    entry_points={
        'pytest11': [
            'pytest_zephyr_scale_integration = pytest_zephyr_scale_integration.conftest',
        ]
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)